@@ -30,27 +30,40 @@
 #include <unistd.h>
 #include "lockfile.h"
 #include "mainwindow.h"
+#include "version.h"
+
+QString starting_home = qEnvironmentVariable("HOME");
 
 int main(int argc, char *argv[])
 {
+    qputenv("XDG_RUNTIME_DIR", "/run/user/0");
     QApplication app(argc, argv);
+    qputenv("HOME", "/root");
     app.setWindowIcon(QIcon::fromTheme(app.applicationName()));
+    app.setApplicationVersion(VERSION);
 
     QTranslator qtTran;
-    if (qtTran.load(QLocale::system(), "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+    if (qtTran.load(QLocale(), QStringLiteral("qt"), QStringLiteral("_"), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
         app.installTranslator(&qtTran);
 
     QTranslator qtBaseTran;
-    if (qtBaseTran.load("qtbase_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+    if (qtBaseTran.load("qtbase_" + QLocale().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
         app.installTranslator(&qtBaseTran);
 
     QTranslator appTran;
-    if (appTran.load(app.applicationName() + "_" + QLocale::system().name(), "/usr/share/" + app.applicationName() + "/locale"))
+    if (appTran.load(app.applicationName() + "_" + QLocale().name(), "/usr/share/" + app.applicationName() + "/locale"))
         app.installTranslator(&appTran);
 
+    // root guard
+    if (QProcess::execute(QStringLiteral("/bin/bash"), {"-c", "logname |grep -q ^root$"}) == 0) {
+        QMessageBox::critical(nullptr, QObject::tr("Error"),
+                              QObject::tr("You seem to be logged in as root, please log out and log in as normal user to use this program."));
+        exit(EXIT_FAILURE);
+    }
+
     if (getuid() == 0) {
         // Don't start app if Synaptic/apt-get is running, lock dpkg otherwise while the program runs
-        LockFile lock_file("/var/lib/dpkg/lock");
+        LockFile lock_file(QStringLiteral("/var/lib/dpkg/lock"));
         if (lock_file.isLocked()) {
             QApplication::beep();
             QMessageBox::critical(nullptr, QObject::tr("Unable to get exclusive lock"),
@@ -64,6 +77,6 @@ int main(int argc, char *argv[])
         w.show();
         return app.exec();
     } else {
-        system("su-to-root -X -c " + QApplication::applicationFilePath().toUtf8() + "&");
+        QProcess::startDetached(QStringLiteral("/usr/bin/mx-cleanup-launcher"), {});
     }
 }
